// ======================================================================
//
// MenuDragBar.cpp
// jeff grills
//
// copyright 1997 origin systems inc 
//
// ======================================================================

#include "first.h"
#include "MenuDragBar.h"

// ======================================================================

MenuDragBar::MenuDragBar(MenuElement *parent, int maxWidth, int maxHeight, Iff *iff)
: MenuElement(parent, maxWidth, maxHeight, NULL)
{
	DEBUG_FATAL(!parent, ("MenuDragBar:: no parent"));
	init();
	load(iff);
}

// ----------------------------------------------------------------------

void MenuDragBar::init(void)
{
	lastX      = 0;
	lastY      = 0;
	oldCapture = NULL;
}

// ----------------------------------------------------------------------

void MenuDragBar::load(Iff *iff)
{
	if (iff)
	{
		MenuElement::load(iff);
	}
}

// ----------------------------------------------------------------------

IoResult MenuDragBar::event(IoEventStruct *event)
{
	Rect absoluteRect;

	getAbsoluteRect(&absoluteRect);

	if (ioIsCapturing())
	{
		// handle dragging the bar around
		if (event->type == IoEventMouseMove)
		{
			// move the parent window
			parent->move(event->mouseX - lastX, event->mouseY - lastY);

			// remember where the mouse is
			lastX = event->mouseX;
			lastY = event->mouseY;
		}

		// handle stop dragging
		if (event->type == IoEventMouseRelease && event->button == 0)
		{
			ioRelease(oldCapture);
			lastX = 0;
			lastY = 0;
			oldCapture = NULL;
		}

		return IoResultBlock;
	}
	else
	{
		// detect press to drag
		if (event->type == IoEventMousePress && event->button == 0 && menuRect.isInInclusive(event->mouseX, event->mouseY))
		{	
			// start capturing input
			oldCapture = ioCapture();

			// remember where the mouse is
			lastX = event->mouseX + absoluteRect.x0;
			lastY = event->mouseY + absoluteRect.y0;
		}
	}

	return MenuElement::event(event);
}

// ======================================================================


